@@ -797,11 +797,13 @@ void build(DbIndex<Index<TText, TIndexSpec>, TDbIndexSpec> & dbIndex,
         for (int i = 1; i < (int)length(dir); ++i)
         {
             if (dir[i - 1] + 1 < dir[i])
-                std::sort(
-                    saBegin + dir[i - 1],
-                    saBegin + dir[i],
-                    QGramLessOffset_<TIndexSAPos, TText const>(text, maxSeedLength, shapeLength));
-
+            {
+		auto infixSA = infix(sa, saBegin + dir[i - 1], saBegin + dir[i]);
+	        sort(
+		    infixSA,
+		    QGramLessOffset_<TIndexSAPos, TText const>(text, maxSeedLength, shapeLength),
+		    Parallel());
+            }
 //            typename Infix<TIndexSAFibre>::Type saInf = infix(sa, dir[i - 1], dir[i]);
 //            _refineQGramIndexBucket(
 //                saInf,
@@ -833,7 +835,7 @@ void build(DbIndex<Index<TText, TIndexSpec>, TDbIndexSpec> & dbIndex,
 //    }
 //
 //    QGramLess_<TIndexSAPos, TText const> less(db.text, MaxValue<TTextSize>::VALUE);
-//    std::sort(begin(sa, Standard()), end(sa, Standard()), less);
+//    sort(sa, less, Parallel());
 }
 
 // ----------------------------------------------------------------------------
@@ -953,7 +955,7 @@ void _buildSA(TIndexSAFibre & sa,
 
     // Construct index using quicksort.
     QGramLess_<TIndexSAPos, TText const> less(db.text, seedLength);
-    std::sort(begin(sa, Standard()), end(sa, Standard()), less);
+    sort(sa, less, Parallel());
 }
 
 // ----------------------------------------------------------------------------
